@@ -18,7 +18,7 @@ class Sequence(object):
         return self.seq_num
 
 
-def sequence(fn):
+def sequence(fn=None):
     """Defines a sequential value for a factory attribute. On each successive
     invocation of this helper (i.e. when a new instance of a document is
     created by the enclosing factory) the given function is passed a
@@ -26,6 +26,9 @@ def sequence(fn):
     value to be used on the model instance."""
     sequence = Sequence()
 
+    if not fn:
+        fn = lambda n: n
+
     def build(*args):
         return fn(sequence.next())
     return build
@@ -41,18 +44,6 @@ def dependent(fn):
     return build
 
 
-def insert_fragment(factory, name):
-    def build(*args):
-        return factory.build_fragment(name)
-    return build
-
-def subdoc(name):
-    """Inserts the document fragment built by the given named factory at a
-    given container attribute."""
-    def build(*args):
-        return monufacture.build(name)
-    return build
-
 
 def id_of(factory, document=None):
     """Creates an instance using the given named factory and returns the
@@ -62,6 +53,11 @@ def id_of(factory, document=None):
     return build
 
 
+def text(*args, **kwargs):
+    """Aliases to random_text."""
+    return random_text(*args, **kwargs)
+
+
 def random_text(length=10, spaces=False, digits=False, upper=True, 
                 lower=True, other_chars=[]):
     """Inserts some random text of the given length into the document."""
@@ -83,16 +79,14 @@ def random_text(length=10, spaces=False, digits=False, upper=True,
     return build
 
 
-def dbref_to(name, type=None):
+def dbref_to(factory, document=None):
     """Create a DBRef-type subdoc structure linking to a new instance of the
     given named factory type."""
-    if not type:
-        type = name
-
+    
     def build(*args):
         return {
-            "$id": monufacture.create(name)["_id"],
-            "$ref": type
+            "$id": monufacture.create(factory, document)["_id"],
+            "$ref": monufacture.get_factory(factory).collection.name
         }
     return build
 
@@ -128,6 +122,9 @@ def date(year=None, month=None, day=None, hour=None, minute=None, second=None, m
         return datetime.now()
     return build_now
 
+def now():
+    """Forwards to date(), allowing the current datetime to be inserted."""
+    return date()
 
 def ago(**kwargs):
     """Returns a function to generate a datetime a time delta in the past from the 
@@ -182,3 +179,15 @@ def one_of(*values):
     def build(*args):
         return random.choice(values)
     return build
+
+
+def random_number(a, b=None):
+    """Inserts a random number in the given range into the document."""
+    def build(*args):
+        return random.randrange(a, b)
+    return build
+
+
+def number(*args, **kwargs):
+    """Alias to random_number."""
+    return random_number(*args, **kwargs)
